@@ -5,4 +5,4 @@ __email__ = 'tic.for.tac@gmail.com'
 __version__ = '0.1.0'
 
 
-from .math_base import factorial, combination
+from .math_base import factorial, permutation, combination
