@@ -28,7 +28,7 @@ def factorial(x: int) -> int:
     return initial
 
 
-def combination(x: int, y: int) -> int:
+def permutation(x: int, y: int) -> int:
     """
 
     @param x:  numerator
@@ -37,3 +37,13 @@ def combination(x: int, y: int) -> int:
     """
     return int(factorial(x) / factorial(y))
 
+
+def combination(x: int, y: int) -> int:
+    """
+
+    @param x:  numerator
+    @param y: denominator
+    @return: comnination value
+    """
+    return int(factorial(x) / (factorial(y) * factorial(x-y)))
+
