@@ -49,5 +49,10 @@ def test_factorial_2():
     assert math_base.factorial(2) == 2
 
 
+def test_permutation():
+    assert math_base.permutation(5, 2) == 60
+
+
 def test_combination():
-    assert math_base.combination(5, 2) == 60
+    assert  math_base.combination(5, 2) == 10
+
